AccessErrorKind

Enum AccessErrorKind 

pub enum AccessErrorKind {
Show 14 variants NoPolicy, UnsupportedAction(Action), OperationDenied, MissingRole { required: BTreeSet<String>, }, MissingScope { required: BTreeSet<String>, }, ColumnDenied { column: String, }, WildcardProjectionDenied, UnsupportedColumnExpression { context: &'static str, }, ExplicitWriteColumnsRequired, JoinedTableColumnPolicyUnsupported, SourceTableColumnPolicyUnsupported, AuxiliaryTableColumnPolicyUnsupported, CteMutationUnsupported, EmptyTable,
}
Specific access denial reason.

Variants



NoPolicy

No matching table policy exists and default decision is deny.



UnsupportedAction(Action)

Command action is not a runtime data action covered by this policy.



OperationDenied

The table policy does not allow this operation.



MissingRole

Required role gate failed.

Fields

required: BTreeSet<String>

Accepted roles.



MissingScope

Required scope gate failed.

Fields

required: BTreeSet<String>

Required scopes.



ColumnDenied

Column is not allowed by the relevant column rule.

Fields

column: String

Normalized column name.



WildcardProjectionDenied

* or table.* cannot be checked against a restrictive column rule.



UnsupportedColumnExpression

A projection expression cannot be mapped to a concrete column.

Fields

context: &'static str

Human-readable context.



ExplicitWriteColumnsRequired

A write used positional or implicit payloads under a restrictive write rule.



JoinedTableColumnPolicyUnsupported

Joined table column policies cannot be enforced by this checker.



SourceTableColumnPolicyUnsupported

Source table column policies cannot be enforced without an explicit source projection.



AuxiliaryTableColumnPolicyUnsupported

UPDATE FROM / DELETE USING table column policies cannot be enforced by this checker.



CteMutationUnsupported

CTE aliases are read-only derived relations.



EmptyTable

Command did not carry a target table.